@@ -1,4 +1,6 @@
-from draftfast.orm import NFLRoster, Player, ShowdownRoster, RosterGroup
+from draftfast.orm import (
+    NFLRoster, Player, ShowdownRoster, RosterGroup, MVPRoster
+)
 from nose import tools as ntool
 
 
@@ -46,6 +48,32 @@ def test_roster_equality_with_position_shuffle():
 
 
 def test_showdown_roster_equality_and_position_shuffle():
+    """
+    In Showdown, point changes result from CPT assignment,
+    so two lineups are not equal given the same player.
+    """
+    player_a = Player(pos='UTIL', name='A', cost=1, team='A')
+    player_a_new_pos = Player(pos='MVP', name='A', cost=1, team='A')
+    player_b = Player(pos='UTIL', name='B', cost=1, team='C')
+    player_c = Player(pos='UTIL', name='C', cost=1, team='D')
+
+    roster_a = MVPRoster()
+    roster_a.add_player(player_a)
+    roster_a.add_player(player_b)
+
+    roster_b = MVPRoster()
+    roster_b.add_player(player_a_new_pos)
+    roster_b.add_player(player_b)
+
+    roster_c = MVPRoster()
+    roster_c.add_player(player_a)
+    roster_c.add_player(player_c)
+
+    ntool.assert_false(roster_a == roster_c)
+    ntool.assert_false(roster_a == roster_b)
+
+
+def test_mvp_roster_equality_and_position_shuffle():
     """
     In Showdown, point changes result from CPT assignment,
     so two lineups are not equal given the same player.
